#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// A demonstration of how to utilize NT7's plot color changing capability.
    /// </summary>
    [Description("A demonstration of how to utilize NT7's plot color changing capability.")]
    public class SampleMultiColoredPlot : Indicator
    {
        #region Variables
		private int 			period = 14;	// Default setting for the SMA's period
		private DataSeries 		middle;			// This DataSeries stores the average of a upper and lower SMA
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.SkyBlue), PlotStyle.Line, "Upper"));
			Add(new Plot(Color.FromKnownColor(KnownColor.SkyBlue), PlotStyle.Line, "Lower"));
			
			// Increase the default widths of the plots
			Plots[0].Pen.Width = 2;
			Plots[1].Pen.Width = 2;
			
            CalculateOnBarClose	= true;
            Overlay				= true;
			
			// Initialize the DataSeries.
			middle = new DataSeries(this);
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Set the plots and the DataSeries.
 			Lower.Set(SMA(Low, Period)[0]);
			Upper.Set(SMA(High, Period)[0]);
			middle.Set((SMA(Low, Period)[0] + SMA(High, Period)[0]) / 2);
			
			// If the average of the two plots is rising, change the plot colors.
			if (Rising(middle))
			{
				// The indexers for PlotColors are PlotColors[plot index][bars back], so the below code would set the first plot (Upper) to black and the second plot (Lower) to green.
				PlotColors[0][0] = Color.Black;
				PlotColors[1][0] = Color.LimeGreen;
			}
			// If the average is falling, change the plot colors.
			else if (Falling(middle))
			{
				PlotColors[0][0] = Color.Red;
				PlotColors[1][0] = Color.Black;
			}
			// If the average remains the same, set both plots to the same color.
			else
			{
				PlotColors[0][0] = Color.Blue;
				PlotColors[1][0] = Color.Blue;
			}
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Upper
        {
            get { return Values[0]; }
        }
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Lower
        {
            get { return Values[1]; }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SampleMultiColoredPlot[] cacheSampleMultiColoredPlot = null;

        private static SampleMultiColoredPlot checkSampleMultiColoredPlot = new SampleMultiColoredPlot();

        /// <summary>
        /// A demonstration of how to utilize NT7's plot color changing capability.
        /// </summary>
        /// <returns></returns>
        public SampleMultiColoredPlot SampleMultiColoredPlot(int period)
        {
            return SampleMultiColoredPlot(Inputs[0], period);
        }

        /// <summary>
        /// A demonstration of how to utilize NT7's plot color changing capability.
        /// </summary>
        /// <returns></returns>
        public SampleMultiColoredPlot SampleMultiColoredPlot(Data.IDataSeries input, int period)
        {
            if (cacheSampleMultiColoredPlot != null)
                for (int idx = 0; idx < cacheSampleMultiColoredPlot.Length; idx++)
                    if (cacheSampleMultiColoredPlot[idx].Period == period && cacheSampleMultiColoredPlot[idx].EqualsInput(input))
                        return cacheSampleMultiColoredPlot[idx];

            lock (checkSampleMultiColoredPlot)
            {
                checkSampleMultiColoredPlot.Period = period;
                period = checkSampleMultiColoredPlot.Period;
            }

            if (cacheSampleMultiColoredPlot != null)
                for (int idx = 0; idx < cacheSampleMultiColoredPlot.Length; idx++)
                    if (cacheSampleMultiColoredPlot[idx].Period == period && cacheSampleMultiColoredPlot[idx].EqualsInput(input))
                        return cacheSampleMultiColoredPlot[idx];

            SampleMultiColoredPlot indicator = new SampleMultiColoredPlot();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
            indicator.MaximumBarsLookBack = MaximumBarsLookBack;
            indicator.Input = input;
            indicator.Period = period;
            indicator.SetUp();

            SampleMultiColoredPlot[] tmp = new SampleMultiColoredPlot[cacheSampleMultiColoredPlot == null ? 1 : cacheSampleMultiColoredPlot.Length + 1];
            if (cacheSampleMultiColoredPlot != null)
                cacheSampleMultiColoredPlot.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheSampleMultiColoredPlot = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// A demonstration of how to utilize NT7's plot color changing capability.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleMultiColoredPlot SampleMultiColoredPlot(int period)
        {
            return _indicator.SampleMultiColoredPlot(Inputs[0], period);
        }

        /// <summary>
        /// A demonstration of how to utilize NT7's plot color changing capability.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleMultiColoredPlot SampleMultiColoredPlot(Data.IDataSeries input, int period)
        {
            return _indicator.SampleMultiColoredPlot(input, period);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// A demonstration of how to utilize NT7's plot color changing capability.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleMultiColoredPlot SampleMultiColoredPlot(int period)
        {
            return _indicator.SampleMultiColoredPlot(Inputs[0], period);
        }

        /// <summary>
        /// A demonstration of how to utilize NT7's plot color changing capability.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleMultiColoredPlot SampleMultiColoredPlot(Data.IDataSeries input, int period)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SampleMultiColoredPlot(input, period);
        }

    }
}
#endregion
